@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::GitVersionCheckCJM;
 # ABSTRACT: Ensure version numbers are up-to-date
 #---------------------------------------------------------------------
 
-our $VERSION = '4.26';
-# This file is part of Dist-Zilla-Plugins-CJM 4.26 (December 13, 2014)
+our $VERSION = '4.27';
+# This file is part of Dist-Zilla-Plugins-CJM 4.27 (August 29, 2015)
 
 
 use version 0.77 ();
@@ -32,6 +32,12 @@ with(
 );
 
 
+has single_version => (
+  is  => 'ro',
+  isa => 'Bool',
+  default => 0,
+);
+
 # RECOMMEND PREREQ: Git::Wrapper
 use Git::Wrapper ();            # AutoPrereqs skips this
 
@@ -109,6 +115,13 @@ sub munge_file
     return 1;
   }
 
+  # If all modules must have the same version,
+  # and the module version is less than the dist version, that's a problem:
+  if ($self->single_version and $version < $distver) {
+    $self->log("ERROR: $pmFile: $version needs to be updated");
+    return 1;
+  }
+
   # If the module hasn't been committed yet, it needs updating:
   #   (since it doesn't match the dist version)
   if ($modifiedRef->{$pmFile}) {
@@ -159,9 +172,9 @@ Dist::Zilla::Plugin::GitVersionCheckCJM - Ensure version numbers are up-to-date
 
 =head1 VERSION
 
-This document describes version 4.26 of
-Dist::Zilla::Plugin::GitVersionCheckCJM, released December 13, 2014
-as part of Dist-Zilla-Plugins-CJM version 4.26.
+This document describes version 4.27 of
+Dist::Zilla::Plugin::GitVersionCheckCJM, released August 29, 2015
+as part of Dist-Zilla-Plugins-CJM version 4.27.
 
 =head1 SYNOPSIS
 
@@ -210,6 +223,14 @@ This FileFinder provides the list of modules that will be checked.
 The default is C<:InstallModules>.  The C<finder> attribute may be
 listed any number of times.
 
+
+=head2 single_version
+
+If set to a true value, all modules in the distribution must have
+the distribution's version.  The default is false, which allows
+unchanged modules to retain the version of the distribution in which
+they were last changed.
+
 =head1 DEPENDENCIES
 
 GitVersionCheckCJM requires L<Dist::Zilla> (4.300009 or later).
@@ -239,7 +260,7 @@ L<< https://github.com/madsen/dist-zilla-plugins-cjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
